@@ -1,11 +1,15 @@
 import json
 
-from bolinette.web import serialize
+from bolinette import core
+from bolinette.testing import Mock
+from bolinette.utils.serializing import serialize
 
 
 class TestClient:
-    def __init__(self, client):
+    def __init__(self, client, context: core.BolinetteContext):
         self.client = client
+        self.context = context
+        self.mock = Mock(context)
         self.cookies = {}
 
     def payload(self, **payload):
